# Module Matrix

| Module | Python Package | Status |
| --- | --- | --- |
| HCS-2 | `standards_sdk_py.hcs2` | Client method parity (`done`) |
| HCS-3 | `standards_sdk_py.hcs3` | Client method parity (`done`) |
| HCS-5 | `standards_sdk_py.hcs5` | Client method parity (`done`) |
| HCS-6 | `standards_sdk_py.hcs6` | Client method parity (`done`) |
| HCS-7 | `standards_sdk_py.hcs7` | Client method parity (`done`) |
| HCS-10 | `standards_sdk_py.hcs10` | Client method parity (`done`) |
| HCS-11 | `standards_sdk_py.hcs11` | Client method parity (`done`) |
| HCS-12 | `standards_sdk_py.hcs12` | Client method parity (`done`) |
| HCS-14 | `standards_sdk_py.hcs14` | Client method parity (`done`) |
| HCS-15 | `standards_sdk_py.hcs15` | Client method parity (`done`) |
| HCS-16 | `standards_sdk_py.hcs16` | Client method parity (`done`) |
| HCS-17 | `standards_sdk_py.hcs17` | Client method parity (`done`) |
| HCS-18 | `standards_sdk_py.hcs18` | Client method parity (`done`) |
| HCS-20 | `standards_sdk_py.hcs20` | Client method parity (`done`) |
| HCS-21 | `standards_sdk_py.hcs21` | Client method parity (`done`) |
| HCS-26 | `standards_sdk_py.hcs26` | Client method parity (`done`) |
| HCS-27 | `standards_sdk_py.hcs27` | Client method parity (`done`) |
| Inscriber | `standards_sdk_py.inscriber` | Function + client parity (`done`) |
| Mirror | `standards_sdk_py.mirror` | HederaMirrorNode parity (`done`) |
| Registry Broker | `standards_sdk_py.registry_broker` | Full operation + client parity (`done`) |

Parity source of truth is `src/standards_sdk_py/parity/parity-manifest.json`.
